ConnectionState

Enum ConnectionState 

pub enum ConnectionState {
    Connected {
        session_state: SessionState,
    },
    Disconnected,
    Error,
    ConnectionPending,
}
Describes the physical network connection state to the kernel server.

Variants



Connected

Active network connection to the server, carrying a nested SessionState.

Fields

session_state: SessionState

The active user authentication session status.



Disconnected

No network connection is active.



Error

Connection attempt failed or an error occurred on the TCP socket.



ConnectionPending

Connection attempt is currently in progress (e.g. TCP handshake ongoing).